@@ -64,26 +64,37 @@ import glob
 CONFIG_DIR = os.path.expanduser("~/.erioon")
 CREDENTIALS_FILE = os.path.join(CONFIG_DIR, "credentials.json")
 
-def save_credentials(user_id: str):
+def save_credentials(user_id: str, project_id: str):
     os.makedirs(CONFIG_DIR, exist_ok=True)
     with open(CREDENTIALS_FILE, "w") as f:
-        json.dump({"user_id": user_id}, f)
+        json.dump(
+            {
+                "user_id": user_id,
+                "project_id": project_id
+            },
+            f
+        )
+
 
 def load_credentials():
-    """Return user_id if already logged in, else None."""
+    """Return (user_id, project_id) if already logged in, else (None, None)."""
     if os.path.exists(CREDENTIALS_FILE):
         try:
             with open(CREDENTIALS_FILE) as f:
                 data = json.load(f)
-            return data.get("user_id")
+                user_id = data.get("user_id")
+                project_id = data.get("project_id")
+            return {"user_id": user_id, "project_id": project_id}
         except Exception:
             pass
     return None
 
+
 def login():
-    existing_user_id = load_credentials()
-    if existing_user_id:
-        print(f"Already logged in with account {existing_user_id}")
+    user_account = load_credentials()
+    if user_account:
+        user_id = user_account.get("user_id")
+        print(f"Already logged in with account {user_id}")
         return
 
     login_method = inquirer.select(
@@ -112,9 +123,13 @@ def login():
         if response.status_code == 200:
             data = response.json()
             user_id = data.get("_id")
-            if user_id:
-                print(f"✅ Welcome! You are now logged in as {user_id}.")
-                save_credentials(user_id)
+            project_id = data.get("project_id")
+            if user_id and project_id:
+                if project_id == "all_projects":
+                    print(f"✅ Welcome! You are now logged in as {user_id} and have full controll.")
+                else:
+                    print(f"✅ Welcome! You are now logged in as {user_id} and have control over project {project_id}.")
+                save_credentials(user_id, project_id)
             else:
                 print(f"❌ Login succeeded but no user_id returned.")
         else:
@@ -136,13 +151,16 @@ def logout():
         print("No account is currently logged in.")
 
 def init():
-    user_id = load_credentials()
-    if not user_id:
+    user_account = load_credentials()
+    print(user_account)
+    if not user_account:
         print("You must be logged in to initialize a project. Run `erioon login` first.")
         return
 
+    user_id = user_account.get("user_id")
+    project_id = user_account.get("project_id")
     headers = {"Content-Type": "application/json"}
-    payload = {"user_id": user_id}
+    payload = {"user_id": user_id, "project_id": project_id}
 
     try:
         response = requests.post(
@@ -185,7 +203,7 @@ def init():
     action_choice = inquirer.select(
         message="What would you like to do?",
         choices=[
-            {"name": "New Playbox", "value": "playbox"},
+            # {"name": "New Playbox", "value": "playbox"},
             {"name": "New Deployment", "value": "deployment"},
         ],
         pointer=">",
