@@ -100,11 +100,12 @@ class ErioonClient:
 
         if response.status_code == 200:
             db_info = response.json()
-            db_project_id = db_info.get("project_id")
+            database_info = db_info.get("database_info")
+            db_project_id = database_info.get("project_id")
             
             if db_project_id != "all_projects":
                 if db_project_id != self.project_id:
-                    return "[ErioonClient] Invalid credentials for this project"
+                    raise Exception("[ErioonClient] Invalid credentials for this project")
             
             sas_info = self.sas_tokens.get(db_id)
             if not sas_info:
