@@ -19,7 +19,8 @@ import uuid
 from io import BytesIO
 import datetime
 from threading import Thread
-import base64
+import random
+import string
 
 # CREATE BLOB CONTAINER
 def create_container_if_not_exists(container_name, container_url):
@@ -183,22 +184,32 @@ def is_duplicate_id(user_id_cont, database, collection, _id, container_url):
                 return True 
     return False
 
+# OPS COUNTER
+def update_ops_counter(database, collection, count, container_client):
+    """
+    Updates the operation count for the current UTC day in ops.msgpack.
+    """
+    from datetime import datetime
+
+    today = datetime.utcnow().date().isoformat()
+    ops_path = f"{database}/{collection}/ops.msgpack"
+    blob_client = container_client.get_blob_client(ops_path)
+
+    try:
+        existing_blob = blob_client.download_blob().readall()
+        ops_data = msgpack.unpackb(existing_blob, raw=False)
+    except Exception:
+        ops_data = {}
+
+    ops_data[today] = ops_data.get(today, 0) + count
+
+    with BytesIO() as buf:
+        buf.write(msgpack.packb(ops_data, use_bin_type=True))
+        buf.seek(0)
+        blob_client.upload_blob(buf, overwrite=True)
+
 # SAVE LOGS
 def save_logs(user_id_cont, database, collection, method, log_type, log_message, count, container_url):
-    """
-    Saves an individual log entry into logs.msgpack inside the container.
-    Each log entry is keyed by a UUID and includes metadata and timestamp.
-
-    Args:
-        user_id_cont: User identifier/context.
-        database: Database name.
-        collection: Collection name.
-        method: HTTP method or operation type (e.g. POST, GET).
-        log_type: Log type e.g. SUCCESS, ERROR.
-        log_message: Detailed message or data for the log.
-        count: Number of records affected or relevant.
-        container_url: Container SAS URL.
-    """
     container_client = ContainerClient.from_container_url(container_url)
     blob_path = f"{database}/{collection}/logs.msgpack"
     logs_blob_client = container_client.get_blob_client(blob=blob_path)
@@ -210,21 +221,25 @@ def save_logs(user_id_cont, database, collection, method, log_type, log_message,
         logs_data = {}
 
     log_id = str(uuid.uuid4())
+    timestamp = datetime.datetime.now().isoformat()
 
     logs_data[log_id] = {
-        "timestamp": datetime.datetime.now().isoformat(),
+        "timestamp": timestamp,
         "method": method.upper(),
         "type": log_type.upper(),
         "log": log_message,
-        "count": count
     }
 
-    # Upload updated logs
+    sorted_logs = sorted(logs_data.items(), key=lambda item: item[1]["timestamp"], reverse=True)
+    trimmed_logs = dict(sorted_logs[:150])
+
     with BytesIO() as out_file:
-        out_file.write(msgpack.packb(logs_data, use_bin_type=True))
+        out_file.write(msgpack.packb(trimmed_logs, use_bin_type=True))
         out_file.seek(0)
         logs_blob_client.upload_blob(out_file, overwrite=True)
-    
+
+    update_ops_counter(database, collection, count, container_client)
+
 # ASYNC LOG SAVING
 def async_log(user_id, db, collection, method, status, message, count, container_url):
     """
@@ -455,9 +470,16 @@ def decode_datetime_from_hex(hex_str):
     millis = int(hex_str, 16)
     return epoch + datetime.timedelta(milliseconds=millis)
 
+def generate_random_prefix(length=10):
+    """
+    Generate a random alphanumeric string of given length.
+    """
+    return ''.join(random.choices(string.ascii_letters + string.digits, k=length))
+
 def generate_next_id(last_id, shard_number):
     """
     last_id format: <datetime_hex>-<shard_hex>-<record_hex>
+    unique identifier: 10 chars
     datetime_hex: 12 chars
     shard_hex: 2 chars
     record_hex: 6 chars
@@ -468,16 +490,16 @@ def generate_next_id(last_id, shard_number):
     else:
         try:
             datetime_hex, shard_hex, record_hex = last_id.split("-")
-            last_dt = decode_datetime_from_hex(datetime_hex)
             last_record_num = int(record_hex, 16)
             record_num = last_record_num + 1
             now = datetime.datetime.utcnow()
         except Exception:
             now = datetime.datetime.utcnow()
             record_num = 1
-
+            
+    random_prefix = generate_random_prefix()
     datetime_hex = encode_datetime_to_hex(now)
     shard_hex = f"{shard_number:08x}"
     record_hex = f"{record_num:06x}"
 
-    return f"{datetime_hex}-{shard_hex}-{record_hex}"
+    return f"{random_prefix}-{datetime_hex}-{shard_hex}-{record_hex}"
